@@ -28,9 +28,11 @@ def lineplot(
     limits: Optional[List[float]] = None,
     independent_x: bool = True,
     independent_y: bool = False,
+    y_axis: Optional[alt.Axis] = None,
     spacing: int = 5,
     color: Optional[Union[str, alt.Color]] = None,
     shape: Optional[Union[str, alt.Shape]] = None,
+    detail: Optional[Union[str, alt.Detail]] = None,
     height: Optional[int] = None,
     width: Optional[int] = None,
 ) -> Chart:
@@ -58,9 +60,11 @@ def lineplot(
         limits: Limits for y-axis
         independent_x: Whether x-axes are independent
         independent_y: Whether y-axes are independent
+        y_axis: Axis for y
         spacing: Spacing between facets
         color: Colorscale
         shape: Shape encoding
+        detail: Detail encoding
         height: Height of plot in facet
         width: Width of plot in facet
 
@@ -77,19 +81,30 @@ def lineplot(
     else:
         shape_kwarg = {"shape": shape}
 
-    if limits is not None:
-        y_scale = alt.Scale(zero=False, domain=limits)
+    if detail is None:
+        detail_kwarg = {}
     else:
-        y_scale = alt.Scale(zero=False)
+        detail_kwarg = {"detail": detail}
+
+    y_kwarg = {}
+
+    if limits is not None:
+        y_kwarg["scale"] = alt.Scale(zero=False, domain=limits)
+    else:
+        y_kwarg["scale"] = alt.Scale(zero=False)
+
+    if y_axis is not None:
+        y_kwarg["axis"] = y_axis
 
     lines_layer = (
         alt.Chart()
         .mark_line()
         .encode(
             x=alt.X(x, title=""),
-            y=alt.Y(y, scale=y_scale, aggregate=aggregate),
+            y=alt.Y(y, aggregate=aggregate, **y_kwarg),
             **color_kwarg,
-            **shape_kwarg
+            **shape_kwarg,
+            **detail_kwarg,
         )
     )
 
@@ -98,9 +113,10 @@ def lineplot(
         .mark_point(filled=True)
         .encode(
             x=alt.X(x, title=""),
-            y=alt.Y(y, scale=y_scale, aggregate=aggregate),
+            y=alt.Y(y, aggregate=aggregate, **y_kwarg),
             **color_kwarg,
-            **shape_kwarg
+            **shape_kwarg,
+            **detail_kwarg,
         )
     )
 
@@ -109,9 +125,10 @@ def lineplot(
         .mark_errorbar(extent=error_extent)
         .encode(
             x=alt.X(x, title=""),
-            y=alt.Y(y, scale=y_scale),
+            y=alt.Y(y, **y_kwarg),
             **color_kwarg,
-            **shape_kwarg
+            **shape_kwarg,
+            **detail_kwarg,
         )
     )
 
